@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /* gifsicle.c - gifsicle's main loop.
-   Copyright (C) 1997-2002 Eddie Kohler, kohler@icir.org
+   Copyright (C) 1997-2007 Eddie Kohler, kohler@icir.org
    This file is part of gifsicle.
 
    Gifsicle is free software. It is distributed under the GNU Public License,
@@ -35,7 +35,8 @@ Gif_Stream *input = 0;
 const char *input_name = 0;
 static int unoptimizing = 0;
 
-int gif_read_flags = 0;
+static int gif_read_flags = 0;
+static int nextfile = 0;
 int gif_write_flags = 0;
 
 static int frames_done = 0;
@@ -181,6 +182,7 @@ static const char *output_option_types[] = {
 #define CROP_TRANSPARENCY_OPT	360
 #define CONSERVE_MEMORY_OPT	361
 #define MULTIFILE_OPT		362
+#define NEXTFILE_OPT		363
 
 #define LOOP_TYPE		(Clp_FirstUserType)
 #define DISPOSAL_TYPE		(Clp_FirstUserType + 1)
@@ -245,6 +247,7 @@ Clp_Option options[] = {
   { "multifile", 0, MULTIFILE_OPT, 0, Clp_Negate },
   
   { "name", 'n', NAME_OPT, Clp_ArgString, 0 },
+  { "nextfile", 0, NEXTFILE_OPT, 0, Clp_Negate },
   { "no-names", 'n', NO_NAME_OPT, 0, Clp_OnlyNegated },
   
   { "optimize", 'O', OPTIMIZE_OPT, Clp_ArgInt, Clp_Negate | Clp_Optional },
@@ -471,6 +474,74 @@ gifread_error(const char *message, int which_image, void *thunk)
   }
 }
 
+struct StoredFile {
+  FILE *f;
+  struct StoredFile *next;
+  char name[1];
+};
+
+static struct StoredFile *stored_files = 0;
+
+static FILE *
+open_giffile(const char *name)
+{
+  struct StoredFile *sf;
+  FILE *f;
+  
+  if (name == 0 || strcmp(name, "-") == 0) {
+#if defined(_MSDOS) || defined(_WIN32)
+    _setmode(_fileno(stdin), _O_BINARY);
+#elif defined(__EMX__)
+    _fsetmode(stdin, "b");
+#endif
+    return stdin;
+  }
+    
+  if (nextfile)
+    for (sf = stored_files; sf; sf = sf->next)
+      if (strcmp(name, sf->name) == 0)
+	return sf->f;
+  
+  f = fopen(name, "rb");
+  
+  if (f && nextfile) {
+    sf = (struct StoredFile *) malloc(sizeof(struct StoredFile) + strlen(name));
+    sf->f = f;
+    sf->next = stored_files;
+    stored_files = sf;
+    strcpy(sf->name, name);
+  }
+  
+  return f;
+}
+
+static void
+close_giffile(FILE *f, int final)
+{
+  struct StoredFile **sf_pprev, *sf;
+  
+  if (!final && nextfile) {
+    int c = getc(f);
+    if (c == EOF)
+      final = 1;
+    else
+      ungetc(c, f);
+  }
+
+  for (sf_pprev = &stored_files; (sf = *sf_pprev); sf_pprev = &sf->next)
+    if (sf->f == f) {
+      if (final) {
+	fclose(f);
+	*sf_pprev = sf->next;
+	free((void *) sf);
+      }
+      return;
+    }
+
+  if (f != stdin)
+    fclose(f);
+}
+
 void
 input_stream(const char *name)
 {
@@ -494,21 +565,14 @@ input_stream(const char *name)
 
   if (infoing == 1)
     set_mode(INFOING);
-  
-  if (name == 0 || strcmp(name, "-") == 0) {
-#if defined(_MSDOS) || defined(_WIN32)
-    _setmode(_fileno(stdin), _O_BINARY);
-#elif defined(__EMX__)
-    _fsetmode(stdin, "b");
-#endif
-    f = stdin;
-    name = "<stdin>";
-    input_name = 0;
-  } else
-    f = fopen(name, "rb");
+
+  f = open_giffile(name);
   if (!f) {
     error("%s: %s", name, strerror(errno));
     return;
+  } else if (f == stdin) {
+    name = "<stdin>";
+    input_name = 0;
   }
   main_name = name;
 
@@ -527,8 +591,9 @@ input_stream(const char *name)
   if (i == EOF) {
     if (!(gif_read_flags & GIF_READ_TRAILING_GARBAGE_OK))
       error("%s: empty file", name);
-    if (f != stdin)
-      fclose(f);
+    else if (nextfile)
+      error("%s: no more images in file", name);
+    close_giffile(f, 1);
     return;
   }
   ungetc(i, f);
@@ -548,9 +613,9 @@ input_stream(const char *name)
     else
       error("%s: trailing garbage ignored", main_name);
     Gif_DeleteStream(gfs);
-    if (verbosing) verbose_close('>');
-    if (f != stdin)
-      fclose(f);
+    if (verbosing)
+      verbose_close('>');
+    close_giffile(f, 1);
     return;
   }
 
@@ -634,10 +699,9 @@ input_stream(const char *name)
   gfs->refcount++;
 
   /* Read more files. */
-  if (gif_read_flags & GIF_READ_TRAILING_GARBAGE_OK)
+  if ((gif_read_flags & GIF_READ_TRAILING_GARBAGE_OK) && !nextfile)
     goto retry_file;
-  else if (f != stdin)
-    fclose(f);
+  close_giffile(f, 0);
 }
 
 void
@@ -724,7 +788,7 @@ do_colormap_change(Gif_Stream *gfs)
 	  any_locals = 1;
       hist = histogram(gfs, &nhist);
       if (nhist <= active_output_data.colormap_size && !any_locals) {
-	warncontext("trivial adaptive palette (only %d colors in source)", nhist);
+	warning("trivial adaptive palette (only %d colors in source)", nhist);
 	return;
       }
     }
@@ -1531,11 +1595,9 @@ main(int argc, char *argv[])
 
      case CAREFUL_OPT: {
        if (clp->negated)
-	 gif_read_flags = gif_write_flags = 0;
-       else {
-	 gif_read_flags = 0;
+	 gif_write_flags = 0;
+       else
 	 gif_write_flags = GIF_WRITE_CAREFUL_MIN_CODE_SIZE;
-       }
        break;
      }
      
@@ -1669,8 +1731,19 @@ main(int argc, char *argv[])
      case MULTIFILE_OPT:
       if (clp->negated)
 	gif_read_flags &= ~GIF_READ_TRAILING_GARBAGE_OK;
-      else
+      else {
 	gif_read_flags |= GIF_READ_TRAILING_GARBAGE_OK;
+	nextfile = 0;
+      }
+      break;
+
+     case NEXTFILE_OPT:
+      if (clp->negated)
+        gif_read_flags &= ~GIF_READ_TRAILING_GARBAGE_OK;
+      else {
+	gif_read_flags |= GIF_READ_TRAILING_GARBAGE_OK;
+	nextfile = 1;
+      }
       break;
 
      case VERSION_OPT:
@@ -1679,7 +1752,7 @@ main(int argc, char *argv[])
 #else
       printf("LCDF Gifsicle %s\n", VERSION);
 #endif
-      printf("Copyright (C) 1997-2005 Eddie Kohler\n\
+      printf("Copyright (C) 1997-2007 Eddie Kohler\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
