@@ -1,18 +1,11 @@
 /* gifwrite.c - Functions to write GIFs.
-   Copyright (C) 1997-2001 Eddie Kohler, eddietwo@lcs.mit.edu
-   This file is part of the GIF library.
+   Copyright (C) 1997-2006 Eddie Kohler, kohler@cs.ucla.edu
+   This file is part of the LCDF GIF library.
 
-   The GIF library is free software*. With the exception of this file, the GIF
-   library is distributed under the GNU General Public License, version 2 or
-   later; you can copy, distribute, or alter it at will, as long as this
-   notice is kept intact and this source code is made available. There is no
-   warranty, express or implied. This file is distributed in the public
-   domain.
-   
-   *There is a patent on the LZW compression method used by GIFs, and included
-   in gifwrite.c. Unisys, the patent holder, allows the compression algorithm
-   to be used without a license in software distributed at no cost to the
-   user. The decompression algorithm is not patented. */
+   The LCDF GIF library is free software. It is distributed under the GNU
+   General Public License, version 2; you can copy, distribute, or alter it at
+   will, as long as this notice is kept intact and this source code is made
+   available. There is no warranty, express or implied. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -38,12 +31,12 @@ extern "C" {
    lot faster. However, it does NOT create "better" results in any way.
    
    Each code is represented by a Node. The Nodes form a tree with variable
-   fan-out -- up to `clear_code' children per Node. There are two kinds of
+   fan-out -- up to 'clear_code' children per Node. There are two kinds of
    Node, TABLE and LINKS. In a TABLE node, the children are stored in a table
    indexed by suffix -- thus, it's very efficient to determine a given child.
    In a LINKS node, the existent children are stored in a linked list. This is
    slightly slower to access. When a LINKS node gets more than
-   `MAX_LINKS_TYPE-1' children, it is converted to a TABLE node. (This is why
+   'MAX_LINKS_TYPE-1' children, it is converted to a TABLE node. (This is why
    it's an adaptive tree.)
    
    Problems with this implementation: MAX_LINKS_TYPE is fixed, so GIFs with
@@ -211,7 +204,7 @@ write_compressed_data(uint8_t **img, uint16_t width, uint16_t height,
   while (1) {
     
     /*****
-     * Output `output_code' to the data stream. */
+     * Output 'output_code' to the data stream. */
 
     leftover |= output_code << bits_left_over;
     bits_left_over += cur_code_bits;
