@@ -23,7 +23,7 @@ int no_warnings = 0;
 
 
 static void
-verror(int seriousness, const char *message, va_list val)
+verror(int seriousness, const char *fmt, va_list val)
 {
   char pattern[BUFSIZ];
   char buffer[BUFSIZ];
@@ -44,12 +44,12 @@ verror(int seriousness, const char *message, va_list val)
   /* try and keep error messages together (no interleaving of error messages
      from two gifsicle processes in the same command line) by calling fprintf
      only once */
-  if (strlen(message) + strlen(pattern) < BUFSIZ) {
-    sprintf(buffer, pattern, message);
+  if (strlen(fmt) + strlen(pattern) < BUFSIZ) {
+    sprintf(buffer, pattern, fmt);
     vfprintf(stderr, buffer, val);
   } else {
     fwrite(pattern, 1, strlen(pattern) - 3, stderr);
-    vfprintf(stderr, message, val);
+    vfprintf(stderr, fmt, val);
     putc('\n', stderr);
   }
 }
@@ -1142,9 +1142,9 @@ fix_total_crop(Gif_Stream *dest, Gif_Image *srci, int merger_index)
      cropped away. This ends up being comments and delay. */
   Gt_Frame *fr = merger[merger_index];
   Gt_Frame *next_fr = 0;
-  Gif_Image *prev_image = 0;
-  if (dest->nimages > 0)
-      prev_image = dest->images[dest->nimages - 1];
+  Gif_Image *prev_image;
+  assert(dest->nimages > 0);
+  prev_image = dest->images[dest->nimages - 1];
   if (merger_index < nmerger - 1)
       next_fr = merger[merger_index + 1];
   
@@ -1360,7 +1360,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
     if (fr->crop) {
       srci = Gif_CopyImage(fr->image);
       Gif_UncompressImage(srci);
-      if (!crop_image(srci, fr->crop)) {
+      if (!crop_image(srci, fr->crop, dest->nimages == 0)) {
 	/* We cropped the image out of existence! Be careful not to make 0x0
 	   frames. */
 	fix_total_crop(dest, srci, i);
